@@ -13,7 +13,9 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
- 
+
+#define _FILE_OFFSET_BITS  64
+#include <config.h>
 #include <gnome.h>
 #include <libgnomevfs/gnome-vfs.h>
 #include <fcntl.h>
@@ -23,6 +25,8 @@
 #include <sys/wait.h>
 #include <sys/stat.h>
 #include <sys/socket.h>
+#include <netinet/in.h>
+#include <arpa/inet.h>
 #include <unistd.h>
 #include <string.h>
 #include "gwget_data.h"
@@ -32,7 +36,7 @@
 #include "utils.h"
 #include "systray.h"
 
-#include <config.h>
+
 
 static gint gwget_data_process_information (GwgetData *gwgetdata);
 static void gwget_data_update_statistics_ui(GwgetData *gwgetdata);
@@ -59,11 +63,11 @@ gwget_data_set_state (GwgetData *gwgetdata, DlState state)
 void 
 gwget_data_update_statistics (GwgetData *gwgetdata) 
 {   
-	guint32 cur_size;
+	guint64 cur_size;
 	time_t cur_time, elapsed_time;
 	struct stat file_stat;
 	gchar buffer[20];
-	guint32 retr_size, remain_size;
+	guint64 retr_size, remain_size;
 	time_t estimated;
 	gdouble perc;
 	gchar *title;
@@ -71,7 +75,7 @@ gwget_data_update_statistics (GwgetData *gwgetdata)
 	
 	/* Get time and size of the file being retrieved */
 	if (stat (gwgetdata->local_filename, &file_stat) != -1) {
-		cur_size = file_stat.st_size;
+		cur_size = (guint64) file_stat.st_size;
 		cur_time = file_stat.st_ctime;
 	} else {
 		cur_size = 0;
@@ -116,7 +120,7 @@ gwget_data_update_statistics (GwgetData *gwgetdata)
 	if (gwgetdata->state == DL_NOT_STARTED)
 		strcpy (buffer, "");
 	else
-		sprintf (buffer, "%d kB", (gwgetdata->total_size + 512) / 1024);
+		sprintf (buffer, "%d kB", (guint32)(gwgetdata->total_size + 512) / 1024);
 	
 	gtk_list_store_set(GTK_LIST_STORE(model),&gwgetdata->file_list,
 						TOTALSIZE_COLUMN,buffer,
@@ -127,7 +131,7 @@ gwget_data_update_statistics (GwgetData *gwgetdata)
 	if (gwgetdata->state == DL_NOT_STARTED || gwgetdata->state == DL_COMPLETED)
 		strcpy (buffer, "");
 	else
-		sprintf (buffer, "%d kB", (gwgetdata->cur_size + 512) / 1024);
+		sprintf (buffer, "%d kB",(guint32) (gwgetdata->cur_size + 512) / 1024);
 	gtk_list_store_set(GTK_LIST_STORE(model),&gwgetdata->file_list,
 						CURRENTSIZE_COLUMN,buffer,
 						-1);
@@ -146,14 +150,18 @@ gwget_data_update_statistics (GwgetData *gwgetdata)
                   			* gwgetdata->session_elapsed) / retr_size)
                 			+ ((gfloat) (gwgetdata->total_time
                              		- gwgetdata->session_elapsed)); 
+		} else {
+			estimated=0;
 		}
 	} else {
 		estimated = 0;
 	}
+
 	if (estimated == 0)
 		strcpy (buffer, "");
 	else
 		convert_time2str (buffer, estimated);
+
 	
 	gtk_list_store_set(GTK_LIST_STORE(model),&gwgetdata->file_list,
 						ESTIMATEDTIME_COLUMN,buffer,
@@ -325,7 +333,8 @@ gwget_data_start_download(GwgetData *gwgetdata)
 	pid_t pid;
 	gint pipe_fd[2];
 	gint number;
-
+	gchar *user_password;
+	user_password=g_strdup("");
 	/* Control the number of download allowed */
 	number=count_download_in_progress();
 
@@ -430,16 +439,27 @@ gwget_data_start_download(GwgetData *gwgetdata)
 			if ( strcmp (gwget_pref.network_mode, "manual") == 0 && 
 			     gwget_pref.http_proxy ) 
 			{
-				setenv("http_proxy",g_strconcat(g_strdup_printf("%s",gwget_pref.http_proxy),":",g_strdup_printf("%d",gwget_pref.http_proxy_port),NULL),1);
-				setenv("ftp_proxy",g_strconcat(g_strdup_printf("%s",gwget_pref.http_proxy),":",g_strdup_printf("%d",gwget_pref.http_proxy_port),NULL),1);
+				if(gwget_pref.proxy_uses_auth) 
+				{
+					user_password=g_strdup_printf("%s:%s@",gwget_pref.proxy_user,gwget_pref.proxy_password);
+				}
+
+				setenv("http_proxy", g_strconcat("http://",g_strdup_printf(user_password),g_strdup_printf("%s",gwget_pref.http_proxy),":",g_strdup_printf("%d",gwget_pref.http_proxy_port),NULL), 1);
+				setenv("ftp_proxy", g_strconcat("http://",g_strdup_printf(user_password),g_strdup_printf("%s",gwget_pref.http_proxy),":",g_strdup_printf("%d",gwget_pref.http_proxy_port),NULL), 1);
 		 	        argv[arg]="-Yon";
 				arg++;
 			}
 			
 			if ( strcmp (gwget_pref.network_mode, "default" ) == 0 && gwget_pref.gnome_http_proxy && gwget_pref.gnome_use_proxy) 
 			{
-				setenv("http_proxy",g_strconcat(g_strdup_printf("%s",gwget_pref.gnome_http_proxy),":",g_strdup_printf("%d",gwget_pref.gnome_http_proxy_port),NULL),1);
-	            		argv[arg]="-Yon";
+				if(gwget_pref.gnome_proxy_uses_auth) 
+				{
+					user_password=g_strdup_printf("%s:%s@",gwget_pref.gnome_proxy_user,gwget_pref.gnome_proxy_password);
+				}
+
+				setenv("http_proxy",g_strconcat("http://",g_strdup_printf(user_password),g_strdup_printf("%s",gwget_pref.http_proxy),":",g_strdup_printf("%d",gwget_pref.http_proxy_port),NULL),1);
+				setenv("ftp_proxy",g_strconcat("http://",g_strdup_printf(user_password),g_strdup_printf("%s",gwget_pref.http_proxy),":",g_strdup_printf("%d",gwget_pref.http_proxy_port),NULL),1);
+		 	        argv[arg]="-Yon";
 				arg++;
 			}
 			
@@ -481,7 +501,7 @@ gwget_data_start_download(GwgetData *gwgetdata)
 }
 
 void
-gwget_data_set_total_size (GwgetData *gwgetdata,guint32 total_size)
+gwget_data_set_total_size (GwgetData *gwgetdata, guint64 total_size)
 {
 	g_return_if_fail (gwgetdata != NULL);
 	gwgetdata->total_size = total_size;
@@ -528,7 +548,7 @@ gwget_data_create(gchar *url, gchar *dir)
 		gnome_vfs_get_file_info (gwgetdata->local_filename, 
 				         info, 
 					 GNOME_VFS_FILE_INFO_DEFAULT);
-		gwgetdata->cur_size = (guint32)info->size;
+		gwgetdata->cur_size = (guint64)info->size;
 	} else {
 		gwgetdata->cur_size = 0;
 	}
@@ -756,3 +776,44 @@ gwget_gnotify_finished(GwgetData *gwgetdata) {
    g_free(fn_msg);
 	g_free(gwgetdata->icon_name);
 }
+
+void
+gwget_data_set_menus (GwgetData *gwgetdata)
+{
+
+
+	if (gwgetdata!=NULL) {
+		if (gwget_data_run(gwgetdata)) {
+			/* Menu items */
+			gtk_widget_set_sensitive(glade_xml_get_widget(xml,"pause_menuitem"),TRUE);
+			gtk_widget_set_sensitive(glade_xml_get_widget(xml,"continue_menuitem"),FALSE);
+			gtk_widget_set_sensitive(glade_xml_get_widget(xml,"cancel_menuitem"),TRUE);
+			/* popup */
+			gtk_widget_set_sensitive(glade_xml_get_widget(xml,"pause_download"),TRUE);
+			gtk_widget_set_sensitive(glade_xml_get_widget(xml,"continue_download"),FALSE);
+			gtk_widget_set_sensitive(glade_xml_get_widget(xml,"cancel_download"),TRUE);
+		} else {
+			if (gwgetdata->state==DL_COMPLETED) {
+				gtk_widget_set_sensitive(glade_xml_get_widget(xml,"continue_menuitem"),FALSE);
+				gtk_widget_set_sensitive(glade_xml_get_widget(xml,"pause_menuitem"),FALSE);
+				gtk_widget_set_sensitive(glade_xml_get_widget(xml,"cancel_menuitem"),FALSE);
+				gtk_widget_set_sensitive(glade_xml_get_widget(xml,"continue_download"),FALSE);
+				gtk_widget_set_sensitive(glade_xml_get_widget(xml,"pause_download"),FALSE);
+				gtk_widget_set_sensitive(glade_xml_get_widget(xml,"cancel_download"),FALSE);
+			} else {
+				gtk_widget_set_sensitive(glade_xml_get_widget(xml,"continue_menuitem"),TRUE);
+				gtk_widget_set_sensitive(glade_xml_get_widget(xml,"pause_menuitem"),FALSE);
+				gtk_widget_set_sensitive(glade_xml_get_widget(xml,"continue_download"),TRUE);
+				gtk_widget_set_sensitive(glade_xml_get_widget(xml,"pause_download"),FALSE);
+			}
+		}
+	} else {
+			gtk_widget_set_sensitive(glade_xml_get_widget(xml,"continue_menuitem"),FALSE);
+			gtk_widget_set_sensitive(glade_xml_get_widget(xml,"pause_menuitem"),FALSE);
+			gtk_widget_set_sensitive(glade_xml_get_widget(xml,"cancel_menuitem"),FALSE);
+			gtk_widget_set_sensitive(glade_xml_get_widget(xml,"continue_download"),FALSE);
+			gtk_widget_set_sensitive(glade_xml_get_widget(xml,"pause_download"),FALSE);
+			gtk_widget_set_sensitive(glade_xml_get_widget(xml,"cancel_download"),FALSE);
+			gtk_widget_set_sensitive(glade_xml_get_widget(xml,"properties_menuitem"),FALSE);
+	}
+}
